@@ -610,7 +610,7 @@ class KiwoomOpenApiPlusTrEventHandler(KiwoomOpenApiPlusEventHandlerForGrpc, Logg
         self.add_callback(self._screen_manager.return_screen, self._scrnno)
         self.add_callback(self.control.DisconnectRealData, self._scrnno)
         KiwoomOpenApiPlusError.try_or_raise(
-            self.control.RateLimitedCommRqData(
+            self.control.RateLimitedCommRqData.async_call(
                 self._rqname, self._trcode, 0, self._scrnno, self._inputs
             )
         )
@@ -690,7 +690,7 @@ class KiwoomOpenApiPlusTrEventHandler(KiwoomOpenApiPlusEventHandlerForGrpc, Logg
             else:
                 try:
                     KiwoomOpenApiPlusError.try_or_raise(
-                        self.control.RateLimitedCommRqData(
+                        self.control.RateLimitedCommRqData.async_call(
                             rqname, trcode, int(prevnext), scrnno, self._inputs
                         )
                     )
@@ -791,9 +791,8 @@ class KiwoomOpenApiPlusKwTrEventHandler(KiwoomOpenApiPlusEventHandlerForGrpc, Lo
         for codes, scrnno in zip(self._code_lists, self._scrnnos):
             self.add_callback(self._screen_manager.return_screen, scrnno)
             self.add_callback(self.control.DisconnectRealData, scrnno)
-            self.add_callback(self.control.SetRealRemove, scrnno, "ALL")
             KiwoomOpenApiPlusError.try_or_raise(
-                self.control.RateLimitedCommKwRqData(
+                self.control.RateLimitedCommKwRqData.async_call(
                     ";".join(codes),
                     0,
                     len(codes),
@@ -816,8 +815,6 @@ class KiwoomOpenApiPlusKwTrEventHandler(KiwoomOpenApiPlusEventHandlerForGrpc, Lo
         splmmsg,
     ):
         if (rqname, trcode) == (self._rqname, self._trcode) and scrnno in self._scrnnos:
-            self.control.SetRealRemove(scrnno, "ALL")
-
             response = KiwoomOpenApiPlusService_pb2.ListenResponse()
             response.name = "OnReceiveTrData"  # pylint: disable=no-member
             response.arguments.add().string_value = scrnno  # pylint: disable=no-member
@@ -858,7 +855,7 @@ class KiwoomOpenApiPlusKwTrEventHandler(KiwoomOpenApiPlusEventHandlerForGrpc, Lo
                         if self._is_stop_condition(row):
                             should_stop = True
                             break
-                        response.listen_response.multi_data.values.add().values.extend(
+                        response.multi_data.values.add().values.extend(
                             row
                         )  # pylint: disable=no-member
 
@@ -874,8 +871,10 @@ class KiwoomOpenApiPlusKwTrEventHandler(KiwoomOpenApiPlusEventHandlerForGrpc, Lo
 
             self.observer.on_next(response)
 
+            self.logger.debug("should_stop: %s", should_stop)
             if should_stop:
                 self._scrnnos_completed[scrnno] = True
+                self.logger.debug("screen_nos_completed: %s", self._scrnnos_completed)
                 if all(self._scrnnos_completed.values()):
                     self.observer.on_completed()
                     return
@@ -996,7 +995,7 @@ class KiwoomOpenApiPlusBaseOrderEventHandler(
                 if self._is_stop_condition(row):
                     should_stop = True
                     break
-                response.listen_response.multi_data.values.add().values.extend(
+                response.multi_data.values.add().values.extend(
                     row
                 )  # pylint: disable=no-member
 
@@ -1099,7 +1098,7 @@ class KiwoomOpenApiPlusOrderEventHandler(
         self.add_callback(self._screen_manager.return_screen, self._scrnno)
         self.add_callback(self.control.DisconnectRealData, self._scrnno)
         KiwoomOpenApiPlusError.try_or_raise(
-            self.control.RateLimitedSendOrder(
+            self.control.RateLimitedSendOrder.async_call(
                 self._rqname,
                 self._scrnno,
                 self._accno,
@@ -1278,13 +1277,15 @@ class KiwoomOpenApiPlusRealEventHandler(KiwoomOpenApiPlusEventHandlerForGrpc, Lo
 
     def on_enter(self):
         for screen_no, code_list in zip(self._screen_nos, self._code_lists):
-            screen_no = self._screen_manager.borrow_screen(screen_no)
             code_list_joined = ";".join(code_list)
+            screen_no = self._screen_manager.borrow_screen(screen_no)
             self.add_callback(self._screen_manager.return_screen, screen_no)
             for code in code_list:
-                self.add_callback(self.control.DelayedSetRealRemove, screen_no, code)
+                self.add_callback(
+                    self.control.SetRealRemove.async_call, screen_no, code
+                )
             KiwoomOpenApiPlusError.try_or_raise(
-                self.control.DelayedSetRealReg(
+                self.control.SetRealReg(
                     screen_no,
                     code_list_joined,
                     self._fid_list_joined,
@@ -1399,7 +1400,7 @@ class KiwoomOpenApiPlusConditionEventHandler(
             self._condition_index,
         )
         KiwoomOpenApiPlusError.try_or_raise_boolean(
-            self.control.RateLimitedSendCondition(
+            self.control.RateLimitedSendCondition.async_call(
                 self._screen_no,
                 self._condition_name,
                 self._condition_index,
@@ -1435,7 +1436,7 @@ class KiwoomOpenApiPlusConditionEventHandler(
             if self._with_info:
                 codes = codelist.rstrip(";").split(";") if codelist else []
                 KiwoomOpenApiPlusError.try_or_raise(
-                    self.control.RateLimitedCommKwRqData(
+                    self.control.RateLimitedCommKwRqData.async_call(
                         codelist,
                         0,
                         len(codes),
@@ -1457,7 +1458,7 @@ class KiwoomOpenApiPlusConditionEventHandler(
             elif should_continue:
                 try:
                     raise KiwoomOpenApiPlusError("Should not reach here")
-                    self.control.RateLimitedSendCondition(
+                    self.control.RateLimitedSendCondition.async_call(
                         self._screen_no,
                         self._condition_name,
                         self._condition_index,
@@ -1493,7 +1494,7 @@ class KiwoomOpenApiPlusConditionEventHandler(
                 codelist = code
                 codes = [code]
                 KiwoomOpenApiPlusError.try_or_raise(
-                    self.control.RateLimitedCommKwRqData(
+                    self.control.RateLimitedCommKwRqData.async_call(
                         codelist,
                         0,
                         len(codes),
@@ -1581,7 +1582,7 @@ class KiwoomOpenApiPlusConditionEventHandler(
                 try:
                     raise KiwoomOpenApiPlusError("Should not reach here")
                     KiwoomOpenApiPlusError.try_or_raise(
-                        self.control.RateLimitedCommKwRqData(
+                        self.control.RateLimitedCommKwRqData.async_call(
                             self._codelist,
                             int(prevnext),
                             len(self._codes),
@@ -1647,14 +1648,14 @@ class KiwoomOpenApiPlusBidirectionalRealEventHandler(
             "Registering code %s to screen %s with type %s", code, screen_no, opt_type
         )
         KiwoomOpenApiPlusError.try_or_raise(
-            self.control.DelayedSetRealReg(screen_no, code, fid_list_joined, opt_type)
+            self.control.SetRealReg(screen_no, code, fid_list_joined, opt_type)
         )
 
     def remove_code(self, code):
         if code in self._screen_by_code:
             screen_no = self._screen_by_code[code]
             self.logger.debug("Removing code %s from screen %s", code, screen_no)
-            self.control.DelayedSetRealRemove(screen_no, code)
+            self.control.SetRealRemove.async_call(screen_no, code)
             self._screen_by_code.pop(code)
             self._code_list_by_screen[screen_no].remove(code)
             self._code_list.remove(code)
