@@ -3,23 +3,28 @@ import threading
 import time
 
 from functools import wraps
+from typing import List
 
 from koapy.utils.logging.Logging import Logging
 
 
 class RateLimiter:
-    def check_sleep_seconds(self):
+    def check_sleep_seconds(self, *args, **kwargs):
         return 0
 
-    def sleep_if_necessary(self):
-        sleep_seconds = self.check_sleep_seconds()
+    def add_call_history(self, *args, **kwargs):
+        pass
+
+    def sleep_if_necessary(self, *args, **kwargs):
+        sleep_seconds = self.check_sleep_seconds(*args, **kwargs)
         if sleep_seconds > 0:
             time.sleep(sleep_seconds)
 
     def __call__(self, func):
         @wraps(func)
         def wrapper(*args, **kwargs):
-            self.sleep_if_necessary()
+            self.sleep_if_necessary(func, *args, **kwargs)
+            self.add_call_history(func, *args, **kwargs)
             return func(*args, **kwargs)
 
         return wrapper
@@ -40,7 +45,7 @@ class TimeWindowRateLimiter(RateLimiter, Logging):
 
         self._call_history = collections.deque(maxlen=self._calls)
 
-    def check_sleep_seconds(self):
+    def check_sleep_seconds(self, *args, **kwargs):
         with self._lock:
             if len(self._call_history) < self._calls:
                 return 0
@@ -48,37 +53,38 @@ class TimeWindowRateLimiter(RateLimiter, Logging):
             remaining = self._call_history[0] + self._period - clock
             return remaining
 
-    def add_call_history(self):
+    def add_call_history(self, *args, **kwargs):
         with self._lock:
             return self._call_history.append(self._clock())
 
-    def sleep_if_necessary(self):
+    def sleep_if_necessary(self, *args, **kwargs):
         with self._lock:
-            sleep_seconds = self.check_sleep_seconds()
+            sleep_seconds = self.check_sleep_seconds(*args, **kwargs)
             if sleep_seconds > 0:
                 time.sleep(sleep_seconds)
-            self.add_call_history()
 
 
 class CompositeTimeWindowRateLimiter(RateLimiter):
-    def __init__(self, limiters):
+    def __init__(self, limiters: List[RateLimiter]):
         super().__init__()
 
         self._lock = threading.RLock()
         self._limiters = limiters
 
-    def check_sleep_seconds(self):
+    def check_sleep_seconds(self, *args, **kwargs):
         with self._lock:
-            return max(limiter.check_sleep_seconds() for limiter in self._limiters)
+            return max(
+                limiter.check_sleep_seconds(*args, **kwargs)
+                for limiter in self._limiters
+            )
 
-    def add_call_history(self):
+    def add_call_history(self, *args, **kwargs):
         with self._lock:
             for limiter in self._limiters:
-                limiter.add_call_history()
+                limiter.add_call_history(*args, **kwargs)
 
-    def sleep_if_necessary(self):
+    def sleep_if_necessary(self, *args, **kwargs):
         with self._lock:
-            sleep_seconds = self.check_sleep_seconds()
+            sleep_seconds = self.check_sleep_seconds(*args, **kwargs)
             if sleep_seconds > 0:
                 time.sleep(sleep_seconds)
-            self.add_call_history()
